\name{MMC}
\alias{MMC}
\non_function{}
\title{ Migratory Motor Complex}
\usage{data(MMC)}
\description{
 This contains the Migratoty Motor Complex data
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{id}{ID of each subject. Repeated for each recurrence}
    \item{time}{recurrence o censoring time}
    \item{event}{censoring status. All event are 1 for each subject 
                 excepting last one that it is 0}
    \item{group}{a factor with levels}
    \item{group}{\code{Males} }
    \item{group}{\code{Females} }
  }
 Note: The group have been created (at random) to illustrate a group comparison

}
\source{
 Husebye E, Skar V, Aalen O and Osnes M (1990), Digestive Diseases and Sciences, p1057
}

\keyword{datasets}
\eof
\name{Survr}
\alias{Survr}
\alias{is.Survr}
\title{ Create a Survival recurrent object}
\description{
 Create a survival recurrent object, usually used as a response variable in a model formula 
}
\usage{
Survr(id, time, event)
is.Survr(x) 
}
\arguments{
  \item{id}{Identificator of each subject. This value is the same for all recurrent times of each subject.}
  \item{time}{time of reccurence. For each subject the last time are censored.}
  \item{event}{The status indicator, 0=no recurrence 1=recurrence. Only this values are accepted. }
  \item{x} {any R object.}
}
\value{
An object of class Survr. Survr objects are implemented as a matrix of 3 colummns. No method for print.

In the case of is.Survr, a logical value T if x inherits from class "Survr", otherwise an F.

}

\seealso{  \code{\link{survfitr}},\code{\link{psh.fit}},\code{\link{wc.fit}},\code{\link{mlefrailty.fit}}  }

\examples{
 data(MMC)
 Survr(MMC$id,MMC$time,MMC$event)
}

\keyword{survival}
\eof

\name{surv.search}
\alias{surv.search}

\title{Calculate the survival in selected times}

\description{

Auxiliary function called from pshPLE, wcPLE
and MLEFrailty.


The estimation using PLE (e.g. Kaplan-Meier) is a decreasing
constant piecewise function with jumps in the times with events. Thus,
to estimate the survival at any time we take the time of the precious event.


}

\usage{
  surv.search(tvals,time,surv) 
 }

\arguments{

\item{tvals}{vector of times where the survival function has to be estimated}
\item{time}{vector of failures times (distinct)}
\item{surv}{vector of survival of each time}
}

\value{
 Returns the survival in each selected time (tvals)
 from a vector of survival values
 }



\examples{
# we have the times 4,7,9,15,21,67
time<-c(4,7,9,15,21,67)

# and its survival (note: in this example there may be more
#                         than one event in some times)
surv<-c(0.8,0.7,0.65,0.55,0.43,0.22)

# We want to calculated the survival at times 1, 10, 32,64
surv.search(c(1,10,32,74),time,surv)

}


\keyword{survival}
\eof
\name{mlefrailty.fit}
\alias{mlefrailty.fit}
\title{Survival function estimator for correlated recurrence time data 
under a Gamma Frailty Model}

\description{
  Estimation of survival function for correlated recurrence time data under a Gamma Frailty model using the maximum likelihood criterion. 
  The resulting object of class "survfitr" is plotted by `plot.survfitr', before it is returned.
}

\usage{
mlefrailty.fit(x,tvals, lambda=NULL, alpha=NULL, alpha.min, alpha.max, 
tol=1e-07, maxiter=500,alpha.console=TRUE)
}


\arguments{
  \item{x}{a survival recurrent event object.}
  \item{tvals}{vector of times where the survival function can be estimated. }
  \item{lambda}{optional vector  of baseline hazard probabilities at t (see details).
   Default is numdeaths/apply(AtRisk,2,sum).}
  \item{alpha}{optional parameter of shape and scale for the frailty distribution. If this 
               parameter is unknown is estimate via EM algorithm. In order to obtain the 
               convergence of this algorithm a seed is calculated (see details).}
  \item{alpha.min}{ optional left bound of the alpha parameter in order to obtain a seed to 
                   estimate alpha parameter. Default value is 0.5.}
  \item{alpha.max}{ optional rigth bound of the alpha parameter in order to obtain a seed to 
                    estimate alpha  parameter. Default value is the maximum of distinct times 
                    of events.}
  \item{tol} {optional tolerance of the EM algorithm used to estimate the alpha parameter. Default is 10e-7}
  \item{maxiter}{optional maximum number of iterations of the EM algorithm used to estimate 
                 the alpha parameter. Default is 500. }
  \item{alpha.console}{if TRUE prints in the console the estimates initial value for alpha and
                       the alpha estimate via the EM algorithm, if FALSE not.}
}

\details{
The product limit estimator developed by Pea, Strawderman and Hollander (2001)
are valid when the interoccurrence times are assumed to represent an IID sample from 
some underlying distribution F. This assumption is clearly restrictive in biomedical
applications, and one obvious generalization that allows association between interocurrence
times is a frailty model. 

A common and convenient choice of frailty distribution is a gamma distribution with shape and scale parameters
set equal to an unknown parameter \eqn{\alpha}. The common marginal survival function can be written
as following

\deqn{\bar {F}(t) =  {\left[ {{\frac{{\alpha }}{{\alpha + \Lambda
_{0} \left( {t} \right)}}}} \right]}^{\alpha}}{%
         1-F(t)=(alpha/(alpha+Lambda_0(t))^alpha}

The parameter \eqn{\alpha} controls the degree of association between interoccurrence 
times within a unit. Pea, Strawderman and Hollander (2001) showed that the estimation of 
\eqn{\alpha} and \eqn{\Lambda_0} can be obtained via the maximisation of the marginal likelihood function 
and the expectation-maximisation (EM) algorithm. For details and the theory behind this
estimator, please refer to Pea, Strawderman and Hollander (2001, JASA). 

In order to obtain a good convergence, \eqn{\alpha} is estimated previously. This 
estimation is used as a initial value in the EM procedure and it's carried out by the 
maximisation of the profile likelihood for \eqn{\alpha}. In this case the arguments 
of \bold{mlefrailty.fit} function called alpha.min and alpha.max are the boundaries 
of this maximisation. The maximum is obtained using the golden section search method.
}

\value{

If the convergence of EM algorithm is not obtained, the initial value of alpha can
be used as a alpha.min argument and recalculate.

\item{n}{number of unit or subjects observed.}
\item{m}{vector of number of recurrences in each subject (length n).}
\item{failed}{vector of number of recurrences in each subject (length n*m). 
              Vector ordered (e.g. times of first unit, times of second unit
              , ..., times of n-unit).}
\item{censored}{vector of times of censorship for each subject (length n).}
\item{numdistinct}{number of distinct failures times.}
\item{distinct}{vector of distinct failures times.}
\item{status}{0 if the estimation is can be provided and 1 if not depending 
              if alpha could be estimate or not. }
\item{alpha}{parameter of Gamma Frailty Model.}
\item{lambda}{Estimates of the hazard probabilities at distinct failures times.} 
\item{survfunc}{vector of survival estimated in distinct times.}
\item{tvals}{copy of argument.}
\item{MLEAttvals}{vector of survival estimated in tvals times.}
}

\references{ Pea, E.A., Strawderman, R. and Hollander, M. (2001). Nonparametric 
             Estimation with Recurrent Event Data. \emph{J. Amer. Statist. Assoc} 
             \bold{96}, 1299-1315.}

\seealso{ \code{\link{survfitr}} \code{\link{Survr}}}

\examples{

data(MMC)
fit<-mlefrailty.fit(Survr(MMC$id,MMC$time,MMC$event))
fit
plot(fit)

# compare with pena-straderman-hollander

fit<-psh.fit(Survr(MMC$id,MMC$time,MMC$event))
fit
lines(fit,lty=2)

# and with wang-chang

fit<-wc.fit(Survr(MMC$id,MMC$time,MMC$event))
fit
lines(fit,lty=3)

}


\keyword{survival}
\eof
\name{plot.survfitr}
\alias{plot.survfitr}
\alias{lines.survfitr}

\title{Plots estimated survival function from an object of class `survrec'.}

\description{Additional plots can be added to the same of axes using `lines.survrec'.}

\usage{
plot.survfitr(x,prob=FALSE,...)
lines.survfitr(x,prob=FALSE, ...)
}

\arguments{
 \item{x}{
    Object of class \code{survrec} (output from calling \code{survrec}
    function).}
 \item{prob}{Print of the probability or survival function if its value is 
              TRUE or FALSE respectively.} 
 \item{...} {additional arguments passed to the plot function.}
}

\value{
  Prints a plot or a line of class \code{survrec}
}

\seealso{\code{\link{psh.fit}} \code{\link{mlefrailty.fit}}  \code{\link{wc.fit}}}

\keyword{survival}
\eof
\name{print.survfitr}
\alias{print.survfitr}
\title{ Print a Short Summary of a Survival Recurrent Curve}
\description{
  Print number of observations, number of events, the restricted mean survival
and its standard error, the median survial and the minimum, maximum and median 
number of recurrences for each subject.
}
\usage{
print.survfitr(x, scale=1, digits=max(options()$digits - 4, 3), ...)
}
\arguments{
  \item{x}{the result of a call to the survfit, psh.fit, wc.fil or mlefrailty.fit functions}
  \item{scale}{a numeric value to rescale the survival time, e.g., if the input data to
survfit were in days, scale=365 would scale the printout to years}
  \item{digits}{number of digits to print}
  \item{\dots}{ other unusued arguments }
}
\details{
   The restricted mean and its standard error are based on a truncated estimator. If the last
observation(s) is not a death, then the survival curve estimate does not fot to zero and the 
mean survival time cannot be estimated. Instead, the quantity reported is the mean of survival
restricted to the time before the last censoring. When the las censoring time is not random 
this quantity is occasionally of interest.

Any randomness in the last censoring time is not taken into account in computing the standard
error of the restricted mean. The restricted mean is shown mainly for compatibility with S.

The median are defined by drawing a horizontal line at 0.5 on the plot of the survival curve.
  
}
\value{
 x, with the invisible flag set
}
\sideeffects{The number of observations, the number of events, the restricted mean survival
and its standard error, the median survival and the minimum, maximum and median number of
recurrences are printed. If there are multiple curves, there is one line of output for each.}

\seealso{ \code{\link{summary.survfitr}},  \code{\link{survfitr}} }

\examples{
data(MMC)
fit<-survfitr(Survr(id,time,event)~group,data=MMC)
print(fit)
}
\keyword{survival }
\eof
\name{psh.fit}

\alias{psh.fit}

\title{Survival function estimator for recurrence time data using the estimator 
developed by Pea, Strawderman and Hollander}

\description{
   Estimation of survival function for recurrence time data by means 
   the generalized product limit estimator (PLE) method developed by 
   Pe a, Strawderman and Hollander. The resulting object of class "survfitr" 
   is plotted by `plot.survfitr', before it is returned.
}

\usage{
   psh.fit(x,tvals) 
}

\arguments{
\item{x}{a survival recurrent event object}
\item{tvals}{vector of times where the survival function can be estimated. }
}

\details{ 
The estimator computed by this object is the nonparametric
estimator of the inter-event time survivor function under the
assumption of a renewal or IID model. This generalizes the
product-limit estimator to the situation where the event is
recurrent. For details and the theory behind this estimator,
please refer to Pe\~na, Strawderman and Hollander (2001, JASA).
}

\value{
\item{n}{number of unit or subjects observed.}
\item{m}{vector of number of recurrences in each subject (length n).}
\item{failed}{vector of number of recurrences in each subject (length n*m). Vector ordered (e.g. times of first unit, times of second unit, ..., times of n-unit)}
\item{censored}{vector of times of censorship for each subject (length n).}
\item{numdistinct}{number of distinct failures times}
\item{distinct}{vector of distinct failures times}
\item{AtRisk}{matrix of number of persons-at-risk at each distinct time and for each subject}
\item{survfunc}{vector of survival estimated in distinct times}
\item{tvals}{copy of argument}
\item{PSHpleAttvals}{vector of survival estimated in tvals times}
}

\references{Pea, E.A., Strawderman, R. and Hollander, M. (2001). Nonparametric Estimation with Recurrent Event Data.  \emph{J. Amer. Statist. Assoc} \bold{96}, 1299-1315.}

\seealso{ \code{\link{survfitr}} \code{\link{Survr}}}

\examples{

data(MMC)
fit<-psh.fit(Survr(MMC$id,MMC$time,MMC$event))
fit
plot(fit)

# compare with MLE Frailty

fit<-mlefrailty.fit(Survr(MMC$id,MMC$time,MMC$event))
fit
lines(fit,lty=2)

# and with wang-chang

fit<-wc.fit(Survr(MMC$id,MMC$time,MMC$event))
fit
lines(fit,lty=3)

}

\keyword{survival}
\eof
\name{summary.survfitr}
\alias{summary.survfitr}
\alias{print.summary.survfitr}

\title{ Summary of a Survival of Recurrences Curve }
\description{
  Returns a matrix containing the survival curve and other information. If 
there are multiple curves, returns a list that contains the previous matrix for
each curve.  
}

\usage{
summary.survfitr(object,...)
}

\arguments{
  \item{object}{output from a call to survfitr, psh.fit, wc.fit or mlefrailty.fit.}
  \item{...}{other unused arguments.}
}

\value{
  For one survival curve returns a matrix, and for multiple curves a list with the
same matrix for each curve.
}

\seealso{ \code{\link{survfitr}} }

\examples{
data(MMC)
summary(survfitr(Survr(id,time,event)~group,data=MMC))
}
\keyword{ survival}
\eof
\name{survfitr}
\alias{survfitr}
\title{ Compute a Survival Curve for Recurrent Event Data}
\description{
 Computes an estimate of a survival curve for recurrent event data using either 
the Pea-Strawderman-Hollander, Wang-Chang or MLE Frailty estimators. The resulting object of class "survfitr" 
   is plotted by `plot.survfitr', before it is returned.
}
\usage{
survfitr(formula, data, type="MLEfrailty",...) 
}

\arguments{
 \item{formula}{A formula object. If a formula object is supplied it must have
a Survr object as the response on the left of the ~ operator and a term on the
right. For a single survival curve the "~1" part of the formula is required.  }
  \item{data}{a data frame in wich to interpret the variables named in the formula.}
  \item{type}{a character string specifying the type of survival curve. Possible
value are "pena-strawderman-hollander", "wang-chang" or "MLEfrailty". The default
is "MLEfrailty". Only the first words are required, e.g "pe","wa","ML"}
\item{...} {additional arguments passed to the type of estimator.
             (see \code{psh.fit}, \code{wc.fit}, or \code{mlefrailty.fit})  }

}
\details{
  See the help details of psh.fit, wc.fit or mlefrailty depending on the type chosen
}
\value{

a survfitr object. Methods defined for survfitr objects are provided for print,plot,lines 
and summary.
}

\references{

1. Pea, E.A., Strawderman, R. and Hollander, M. (2001). Nonparametric Estimation with Recurrent Event Data.  \emph{J. Amer. Statist. Assoc} \bold{96}, 1299-1315. \cr
2. Wang, M.-C. and Chang, S.-H. (1999). Nonparametric Estimation of a Recurrent Survival Function. \emph{J. Amer. Statist. Assoc} \bold{94}, 146-153.

}

\seealso{\code{\link{print.survfitr}},\code{\link{plot.survfitr}},
   \code{\link{lines.survfitr}}, \code{\link{summary.survfitr}},
  \code{\link{Survr}},\code{\link{psh.fit}},\code{\link{wc.fit}},
  \code{\link{mlefrailty.fit}}  }

\examples{
  data(MMC)
  # fit a pena-strawderman-hollander and plot it
  fit<-survfitr(Survr(id,time,event)~group,data=MMC,type="pena")
  plot(fit)
  # print the survival estimators
  fit
  summary(fit)

  # fit a MLE Frailty and plot it
  fit<-survfitr(Survr(id,time,event)~group,data=MMC,type="MLE")
  plot(fit)
  # print the survival estimators
  fit
  summary(fit)

}


\keyword{survival }
\eof
\name{wc.fit}

\alias{wc.fit}

\title{Survival function estimator for recurrence time data using the 
estimator developed by Wang and Chang.}

\description{Estimation of survival function for correlated or i.i.d. recurrence 
time data by means of the product limit estimator (PLE) method developed by Wang and Chang.
The resulting object of class "survfitr" is plotted by `plot.survfitr', before it is returned.
}

\usage{
wc.fit(x,tvals) 
}

\arguments{
\item{x}{a survival recurrent event object.}
\item{tvals}{vector of times where the survival function can be estimated. }
}

\value{
\item{n}{number of unit or subjects observed.}
\item{m}{vector of number of recurrences in each subject (length n).}
\item{failed}{vector of number of recurrences in each subject (length n*m). Vector ordered (e.g. times of first unit, times of second unit, ..., times of n-unit)}
\item{censored}{vector of times of censorship for each subject (length n).}
\item{numdistinct}{number of distinct failures times.}
\item{distinct}{vector of distinct failures times.}
\item{AtRisk}{matrix of number of persons-at-risk at each distinct time and for each subject.}
\item{survfunc}{vector of survival estimated in distinct times.}
\item{tvals}{copy of argument.}
\item{PSHpleAttvals}{vector of survival estimated in tvals times.}
}

\details{
Wang and Chang (1999) proposed an estimator of the common marginal survivor function in the 
case where within-unit interrocurence times are correlated. The correlation structure 
considered by Wang and Chang (1999) is quite general and contains, in particular, 
both the i.i.d. and multiplicative (hence gamma) frailty model as special cases. 

This estimator removes the bias noted for the produc-limit estimator developed by 
Pea, Strawderman and Hollander (PSH, 2001) when interrocurence times are correlated within 
units. However, when applied to i.i.d. interocurrence times, this estimator is not expected 
to perform as well as the PSH estimator, especially with regard to efficiency.
}

\references{

Wang, M.-C. and Chang, S.-H. (1999). Nonparametric Estimation of a Recurrent Survival Function. \emph{J. Amer. Statist. Assoc} \bold{94}, 146-153.

}

\seealso{ \code{\link{survfitr}} \code{\link{Survr}}}

\examples{

data(MMC)

fit<-wc.fit(Survr(MMC$id,MMC$time,MMC$event))
fit
plot(fit)

# compare with pena-straderman-hollander

fit<-psh.fit(Survr(MMC$id,MMC$time,MMC$event))
fit
lines(fit,lty=2)

# and with MLE frailty

fit<-mlefrailty.fit(Survr(MMC$id,MMC$time,MMC$event))
fit
lines(fit,lty=3)

}



\keyword{survival}

\eof
